/*
 * UnderConstructionPage
 * People at Work #2 theme CSS
 * (c) WebFactory Ltd, 2015 - 2021
 */


html {
   height: 100%;
   padding: 0;
   margin: 0;
}

body {
  font-weight: 400;
  font-size: 14px;
  line-height: 120%;
  color: #2C3D55;
  background: radial-gradient(circle, transparent 20%, slategray 20%, slategray 80%, transparent 80%, transparent),
radial-gradient(circle, transparent 20%, slategray 20%, slategray 80%, transparent 80%, transparent) 50px 50px,
linear-gradient(#A8B1BB 8px, transparent 8px) 0 -4px,
linear-gradient(90deg, #A8B1BB 8px, transparent 8px) -4px 0;
background-color: slategray;
background-size: 100px 100px, 100px 100px, 50px 50px, 50px 50px;
  padding: 0;
  margin: 0;
}

#hero-image {
  text-align: center;
  margin: 20px auto 10px auto;
}

#hero-image img {
  max-width: 80%;
}

.container {
  background-color: rgba(168, 177, 187, 0.85);
}

h1 {
  font-size: 34px;
  color: #2C3D55;
  font-family: "Nunito", sans-serif;
  font-weight: 900;
  margin: 20px 0 30px 0;
  text-align: center;
}

.content {
  text-align: center;
  font-family: "Helvetica", "Arial", sans-serif;
}

#social {
  text-align: center;
  margin-top: 30px;
}

#social a i {
  color: #2C3D55;
  margin: 10px;
  box-sizing: content-box;
}

#social a:hover i {
  color: #fbe99a;
}

@media(max-width:767px){
  h1 {
     font-size: 30px;
     margin: 10px 0 30px 0;
  }
  #hero-image img {
    max-width: 95%;
  }
}
