/**
 * Colors
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
:root {
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color--rgb: 0, 124, 186;
  --wp-admin-theme-color-darker-10: #006ba1;
  --wp-admin-theme-color-darker-10--rgb: 0, 107, 161;
  --wp-admin-theme-color-darker-20: #005a87;
  --wp-admin-theme-color-darker-20--rgb: 0, 90, 135;
  --wp-admin-border-width-focus: 2px;
}
@media (-webkit-min-device-pixel-ratio: 2), (min-resolution: 192dpi) {
  :root {
    --wp-admin-border-width-focus: 1.5px;
  }
}

.editor-styles-wrapper .wp-block {
  margin-right: auto;
  margin-left: auto;
}

html :where(.editor-styles-wrapper) {
  padding: 8px;
}
html :where(.editor-styles-wrapper) .block-editor-block-list__layout.is-root-container > .wp-block[data-align=full] {
  margin-right: -8px;
  margin-left: -8px;
}

html :where(.wp-block) {
  max-width: 840px;
  margin-top: 28px;
  margin-bottom: 28px;
}
html :where(.wp-block)[data-align=wide] {
  max-width: 1100px;
}
html :where(.wp-block)[data-align=full] {
  max-width: none;
}
html :where(.wp-block)[data-align=left], html :where(.wp-block)[data-align=right] {
  width: 100%;
  height: 0;
}
html :where(.wp-block)[data-align=left]::before, html :where(.wp-block)[data-align=right]::before {
  content: none;
}
html :where(.wp-block)[data-align=left] > * {
  float: left;
  margin-right: 2em;
}
html :where(.wp-block)[data-align=right] > * {
  float: right;
  margin-left: 2em;
}
html :where(.wp-block)[data-align=full], html :where(.wp-block)[data-align=wide] {
  clear: both;
}

.wp-block-group > [data-align=full] {
  margin-right: auto;
  margin-left: auto;
}

.wp-block-group.has-background > [data-align=full] {
  margin-right: -30px;
  width: calc(100% + 60px);
}

/**
* Group: Full Width Alignment
*/
[data-align=full] .wp-block-group > .wp-block {
  padding-right: 14px;
  padding-left: 14px;
}
@media (min-width: 600px) {
  [data-align=full] .wp-block-group > .wp-block {
    padding-right: 0;
    padding-left: 0;
  }
}
[data-align=full] .wp-block-group > [data-align=full] {
  padding-left: 0;
  padding-right: 0;
  right: 0;
  width: 100%;
  max-width: none;
}
[data-align=full] .wp-block-group.has-background > [data-align=full] {
  width: calc(100% + 60px);
}