/**
 * Colors
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
*  Converts a hex value into the rgb equivalent.
*
* @param {string} hex - the hexadecimal value to convert
* @return {string} comma separated rgb values
*/
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
.wp-block[data-align=center] > .wp-block-site-logo,
.wp-block-site-logo.aligncenter > div {
  display: table;
  margin-left: auto;
  margin-right: auto;
}

.wp-block-site-logo a {
  pointer-events: none;
}
.wp-block-site-logo .custom-logo-link {
  cursor: inherit;
}
.wp-block-site-logo .custom-logo-link:focus {
  box-shadow: none;
}
.wp-block-site-logo .custom-logo-link.is-transient img {
  opacity: 0.3;
}
.wp-block-site-logo img {
  display: block;
  height: auto;
  max-width: 100%;
}

.wp-block-site-logo.wp-block-site-logo .components-placeholder,
.wp-block-site-logo.wp-block-site-logo .components-resizable-box__container {
  border-radius: inherit;
}
.wp-block-site-logo.wp-block-site-logo.is-default-size .components-placeholder {
  height: 120px;
  width: 120px;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder {
  display: flex;
  justify-content: center;
  align-items: center;
  box-shadow: none;
  padding: 0;
  min-height: 48px;
  min-width: 48px;
  height: 100%;
  width: 100%;
  color: currentColor;
  background: transparent;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-form-file-upload {
  display: none;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-placeholder__preview {
  position: absolute;
  top: 4px;
  right: 4px;
  bottom: 4px;
  left: 4px;
  background: rgba(255, 255, 255, 0.8);
  display: flex;
  align-items: center;
  justify-content: center;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-drop-zone__content-text {
  display: none;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder::before {
  content: "";
  display: block;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border: 1px dashed currentColor;
  opacity: 0.4;
  pointer-events: none;
  border-radius: inherit;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-placeholder__fieldset {
  width: auto;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-button.components-button {
  color: inherit;
  padding: 0;
  display: flex;
  justify-content: center;
  align-items: center;
  width: 48px;
  height: 48px;
  border-radius: 50%;
  position: relative;
  visibility: hidden;
  background: transparent;
  transition: all 0.1s linear;
}
@media (prefers-reduced-motion: reduce) {
  .wp-block-site-logo.wp-block-site-logo .components-placeholder .components-button.components-button {
    transition-duration: 0s;
    transition-delay: 0s;
  }
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-button.components-button > svg {
  color: #fff;
}
.wp-block-site-logo.wp-block-site-logo .components-placeholder .components-placeholder__illustration {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  stroke: currentColor;
  stroke-dasharray: 3;
  opacity: 0.4;
}
.wp-block-site-logo.wp-block-site-logo.is-selected .components-button.components-button {
  background: var(--wp-admin-theme-color);
  border-color: var(--wp-admin-theme-color);
  border-style: solid;
  color: #fff;
  opacity: 1;
  visibility: visible;
}